@@ -9,21 +9,21 @@
 # @arguments function that tests columns for inclusion
 # @alias catcolwise
 # @alias numcolwise
-colwise <- function(fun., .if = function(x) TRUE) {
+colwise <- function(.fun, .if = function(x) TRUE) {
   function(df, ...) {
     filtered <- Filter(.if, df)
     if (ncol(filtered) == 0) return(data.frame())
     
-    df <- do.call("data.frame", alply(filtered, 2, fun., ...))
+    df <- do.call("data.frame", alply(filtered, 2, .fun, ...))
     names(df) <- names(filtered)
     df
   }
 }
 
-catcolwise <- function(fun., .try = FALSE) {
-  colwise(fun., .if = is.discrete)
+catcolwise <- function(.fun, .try = FALSE) {
+  colwise(.fun, .if = is.discrete)
 }
-numcolwise <- function(fun., .try = FALSE) {
-  colwise(fun., .if = is.numeric)
+numcolwise <- function(.fun, .try = FALSE) {
+  colwise(.fun, .if = is.numeric)
 }
 
