@@ -2,15 +2,15 @@
 # For each element of a list, apply function then combine results into a data  frame
 # 
 # All plyr functions use the same split-apply-combine strategy: they split the
-# input into simpler pieces, apply \code{fun.} to each piece, and then combine
+# input into simpler pieces, apply \code{.fun} to each piece, and then combine
 # the pieces into a single data structure.  This function splits lists by
 # elements and combines the result into a data frame.  If there are no
 # results, then this function will return a data frame with zero rows and
 # columns (\code{data.frame()}).
 # 
-# The most unambiguous behaviour is achieved when \code{fun.} returns a 
+# The most unambiguous behaviour is achieved when \code{.fun} returns a 
 # data frame - in that case pieces will be combined with
-# \code{\link{rbind.fill}}.  If \code{fun.} returns an atomic vector of fixed
+# \code{\link{rbind.fill}}.  If \code{.fun} returns an atomic vector of fixed
 # length, it will be \code{rbind}ed together and converted to a data frame.
 # Any other values will result in an error.
 # 
@@ -20,12 +20,12 @@
 # @keyword manip
 # @arguments list to be processed
 # @arguments function to apply to each piece
-# @arguments other arguments passed on to \code{fun.}
+# @arguments other arguments passed on to \code{.fun}
 # @arguments name of the progress bar to use, see \code{\link{create_progress_bar}}
 # @value a data frame
-ldply <- function(data., fun. = NULL, ..., progress. = "none") {
-  if (!is(data., "split")) data. <- as.list(data.)
-  res <- llply(data., fun., ..., progress. = progress.)
+ldply <- function(.data, .fun = NULL, ..., .progress = "none") {
+  if (!is(.data, "split")) .data <- as.list(.data)
+  res <- llply(.data = .data, .fun = .fun, ..., .progress = .progress)
   # Just want to treat as a list in here
   attr(res, "split_labels") <- NULL
   
@@ -49,8 +49,8 @@ ldply <- function(data., fun. = NULL, ..., progress. = "none") {
     rows <- laply(res, function(x) if(is.null(x)) 0 else nrow(x))
   }
 
-  labels <- attr(data., "split_labels")
-  if (!is.null(labels) && nrow(labels) == length(data.)) {
+  labels <- attr(.data, "split_labels")
+  if (!is.null(labels) && nrow(labels) == length(.data)) {
     cols <- setdiff(names(labels), names(resdf))
     resdf <- cbind(labels[rep(1:nrow(labels), rows), cols, drop=FALSE], resdf)
   }
@@ -62,15 +62,15 @@ ldply <- function(data., fun. = NULL, ..., progress. = "none") {
 # For each subset of a data frame, apply function then combine results into a  data frame
 # 
 # All plyr functions use the same split-apply-combine strategy: they split the
-# input into simpler pieces, apply \code{fun.} to each piece, and then combine
+# input into simpler pieces, apply \code{.fun} to each piece, and then combine
 # the pieces into a single data structure.  This function splits data frames
 # by variables and combines the result into a data frame.  If there are no 
 # results, then this function will return a data frame with zero rows and
 # columns (\code{data.frame()}).
 # 
-# The most unambiguous behaviour is achieved when \code{fun.} returns a 
+# The most unambiguous behaviour is achieved when \code{.fun} returns a 
 # data frame - in that case pieces will be combined with
-# \code{\link{rbind.fill}}.  If \code{fun.} returns an atomic vector of fixed
+# \code{\link{rbind.fill}}.  If \code{.fun} returns an atomic vector of fixed
 # length, it will be \code{rbind}ed together and converted to a data frame.
 # Any other values will result in an error.
 # 
@@ -81,7 +81,7 @@ ldply <- function(data., fun. = NULL, ..., progress. = "none") {
 # @arguments data frame to be processed
 # @arguments variables to split data frame by, as quoted variables, a formula or character vector
 # @arguments function to apply to each piece
-# @arguments other arguments passed on to \code{fun.}
+# @arguments other arguments passed on to \code{.fun}
 # @arguments name of the progress bar to use, see \code{\link{create_progress_bar}}
 # @value a data frame
 #X mean_rbi <- function(df) mean(df$rbi, na.rm=TRUE)
@@ -95,19 +95,19 @@ ldply <- function(data., fun. = NULL, ..., progress. = "none") {
 #X base2 <- ddply(baseball, .(id), function(df) {
 #X  transform(df, career_year = year - min(year) + 1)
 #X })
-ddply <- function(data., variables., fun. = NULL, ..., progress. = "none") {
-  data. <- as.data.frame(data.)
-  variables. <- as.quoted(variables.)
-  pieces <- splitter_d(data., variables.)
+ddply <- function(.data, .variables, .fun = NULL, ..., .progress = "none") {
+  .data <- as.data.frame(.data)
+  .variables <- as.quoted(.variables)
+  pieces <- splitter_d(.data, .variables)
   
-  ldply(pieces, fun., ..., progress. = progress.)
+  ldply(.data = pieces, .fun = .fun, ..., .progress = .progress)
 }
 
 # Split array, apply function, and return results in a data frame
 # For each slice of an array, apply function then combine results into a data frame
 # 
 # All plyr functions use the same split-apply-combine strategy: they split the
-# input into simpler pieces, apply \code{fun.} to each piece, and then combine
+# input into simpler pieces, apply \code{.fun} to each piece, and then combine
 # the pieces into a single data structure. This function splits matrices,
 # arrays and data frames by dimensions and combines the result into a data
 # frame. If there are no results, then this function will return a data frame
@@ -120,11 +120,11 @@ ddply <- function(data., variables., fun. = NULL, ..., progress. = "none") {
 # @arguments matrix, array or data frame to be processed
 # @arguments a vector giving the subscripts to split up \code{data} by.  1 splits up by rows, 2 by columns and c(1,2) by rows and columns, and so on for higher dimensions
 # @arguments function to apply to each piece
-# @arguments other arguments passed on to \code{fun.}
+# @arguments other arguments passed on to \code{.fun}
 # @arguments name of the progress bar to use, see \code{\link{create_progress_bar}}
 # @value a data frame
-adply <- function(data., margins., fun. = NULL, ..., progress. = "none") {
-  pieces <- splitter_a(data., margins.)
+adply <- function(.data, .margins, .fun = NULL, ..., .progress = "none") {
+  pieces <- splitter_a(.data, .margins)
   
-  ldply(pieces, fun., ..., progress. = progress.)
+  ldply(.data = pieces, .fun = .fun, ..., .progress = .progress)
 }
\ No newline at end of file
