@@ -2,7 +2,7 @@
 # For each element of a list, apply function then combine results into a list
 # 
 # All plyr functions use the same split-apply-combine strategy: they split the
-# input into simpler pieces, apply \code{fun.} to each piece, and then combine
+# input into simpler pieces, apply \code{.fun} to each piece, and then combine
 # the pieces into a single data structure.  This function splits lists by
 # elements and combines the result into a list.  If there are no results, then
 # this function will return a list of length 0  (\code{list()}).
@@ -16,7 +16,7 @@
 # @keyword manip
 # @arguments list to be processed
 # @arguments function to apply to each piece
-# @arguments other arguments passed on to \code{fun.}
+# @arguments other arguments passed on to \code{.fun}
 # @arguments name of the progress bar to use, see \code{\link{create_progress_bar}}
 # @value list of results
 # 
@@ -27,25 +27,26 @@
 #X
 #X llply(x, mean)
 #X llply(x, quantile, probs = 1:3/4)
-llply <- function(data., fun. = NULL, ..., progress. = "none") {
-  if (!is(data., "split")) data. <- as.list(data.)
-  if (is.null(fun.)) return(data.)
-  if (length(data.) == 0) return(list())
+llply <- function(.data, .fun = NULL, ..., .progress = "none") {
+  if (!is(.data, "split")) .data <- as.list(.data)
+  if (is.null(.fun)) return(.data)
+  if (length(.data) == 0) return(list())
   
-  if (is.character(fun.)) fun. <- match.fun(fun.)
+  if (is.character(.fun)) .fun <- match.fun(.fun)
+  if (!is.function(.fun)) stop(".fun is not a function.")
   
-  progress <- create_progress_bar(progress.)
+  progress <- create_progress_bar(.progress)
   
-  progress$init(length(data.))
+  progress$init(length(.data))
 
   f2 <- function(...) {
-    res <- fun.(...)
+    res <- .fun(...)
     progress$step()
     res
   }
   
-  result <- lapply(data., f2, ...)
-  mostattributes(result) <- attributes(data.)
+  result <- lapply(.data, f2, ...)
+  mostattributes(result) <- attributes(.data)
   progress$term()
   
   result
@@ -55,7 +56,7 @@ llply <- function(data., fun. = NULL, ..., progress. = "none") {
 # For each subset of a data frame, apply function then combine results into a  list
 # 
 # All plyr functions use the same split-apply-combine strategy: they split the
-# input into simpler pieces, apply \code{fun.} to each piece, and then combine
+# input into simpler pieces, apply \code{.fun} to each piece, and then combine
 # the pieces into a single data structure.  This function splits data frames
 # by variables and combines the result into a list.  If there are no results,
 # then this function will return a list of length 0  (\code{list()}).
@@ -70,7 +71,7 @@ llply <- function(data., fun. = NULL, ..., progress. = "none") {
 # @arguments data frame to be processed
 # @arguments variables to split data frame by, as quoted variables, a formula or character vector
 # @arguments function to apply to each piece
-# @arguments other arguments passed on to \code{fun.}
+# @arguments other arguments passed on to \code{.fun}
 # @arguments name of the progress bar to use, see \code{\link{create_progress_bar}}
 # @value if results are atomic with same type and dimensionality, a vector, matrix or array; otherwise, a list-array (a list with dimensions)
 # @value list of results
@@ -82,19 +83,19 @@ llply <- function(data., fun. = NULL, ..., progress. = "none") {
 #X with(coef, plot(`(Intercept)`, year))
 #X qual <- laply(models, function(mod) summary(mod)$r.squared)
 #X hist(qual)
-dlply <- function(data., variables., fun. = NULL, ..., progress. = "none") {
-  data. <- as.data.frame(data.)
-  variables. <- as.quoted(variables.)
-  pieces <- splitter_d(data., variables.)
+dlply <- function(.data, .variables, .fun = NULL, ..., .progress = "none") {
+  .data <- as.data.frame(.data)
+  .variables <- as.quoted(.variables)
+  pieces <- splitter_d(.data, .variables)
   
-  llply(pieces, fun., ..., progress. = progress.)
+  llply(.data = pieces, .fun = .fun, ..., .progress = .progress)
 }
 
 # Split array, apply function, and return results in a list
 # For each slice of an array, apply function then combine results into a list
 # 
 # All plyr functions use the same split-apply-combine strategy: they split the
-# input into simpler pieces, apply \code{fun.} to each piece, and then combine
+# input into simpler pieces, apply \code{.fun} to each piece, and then combine
 # the pieces into a single data structure.  This function splits matrices,
 # arrays and data frames by dimensions and combines the result into a list. 
 # If there are no results, then this function will return a list of length 0 
@@ -110,14 +111,14 @@ dlply <- function(data., variables., fun. = NULL, ..., progress. = "none") {
 # @arguments matrix, array or data frame to be processed
 # @arguments a vector giving the subscripts to split up \code{data} by.  1 splits up by rows, 2 by columns and c(1,2) by rows and columns, and so on for higher dimensions
 # @arguments function to apply to each piece
-# @arguments other arguments passed on to \code{fun.}
+# @arguments other arguments passed on to \code{.fun}
 # @arguments name of the progress bar to use, see \code{\link{create_progress_bar}}
 # @value list of results
 # 
 #X alply(ozone, 3, quantile)
 #X alply(ozone, 3, function(x) table(round(x)))
-alply <- function(data., margins., fun. = NULL, ..., progress. = "none") {
-  pieces <- splitter_a(data., margins.)
+alply <- function(.data, .margins, .fun = NULL, ..., .progress = "none") {
+  pieces <- splitter_a(.data, .margins)
   
-  llply(pieces, fun., ..., progress. = progress.)
+  llply(.data = pieces, .fun = .fun, ..., .progress = .progress)
 }
